@@ -1,6 +1,6 @@
 package Search::Elasticsearch::Client::2_0;
 
-our $VERSION='5.00';
+our $VERSION='5.01';
 use Search::Elasticsearch 5.00 ();
 
 1;
@@ -11,23 +11,23 @@ use Search::Elasticsearch 5.00 ();
 
 =head1 NAME
 
-Search::Elasticsearch::Client::2_0 - Thin client with full support for Elasticsearch 1.x APIs
+Search::Elasticsearch::Client::2_0 - Thin client with full support for Elasticsearch 2.x APIs
 
 =head1 VERSION
 
-version 5.00
+version 5.01
 
 =head1 DESCRIPTION
 
-The L<Search::Elasticsearch::Client::1_0> package provides a client
+The L<Search::Elasticsearch::Client::2_0> package provides a client
 compatible with Elasticsearch 1.x.  It should be used in conjunction
 with L<Search::Elasticsearch> as follows:
 
     $e = Search::Elasticsearch->new(
-        client => "1_0::Direct"
+        client => "2_0::Direct"
     );
 
-See C<Search::Elasticsearch::Client::1_0::Direct> for documentation
+See L<Search::Elasticsearch::Client::2_0::Direct> for documentation
 about how to use the client itself.
 
 =head1 AUTHOR
@@ -46,5 +46,5 @@ This is free software, licensed under:
 
 __END__
 
-# ABSTRACT: Thin client with full support for Elasticsearch 1.x APIs
+# ABSTRACT: Thin client with full support for Elasticsearch 2.x APIs
 
